pub enum SubmitOutcome {
Submitted,
WaitingForConfiguration,
Reconfigured,
WaitingForKeyframe,
DroppedForBackpressure,
}Expand description
Result of offering an access unit to a low-latency decoder.
Variants
Submitted
Frame was accepted by the platform decoder.
WaitingForConfiguration
Parameter sets have not yet formed a complete decoder configuration.
Reconfigured
Decoder was reconfigured and accepted this frame.
WaitingForKeyframe
A delta frame was intentionally skipped until the next keyframe.
DroppedForBackpressure
Decoder queue was full and the frame was dropped.