pub struct DecoderStats {
pub access_units_received: u64,
pub access_units_submitted: u64,
pub waiting_drops: u64,
pub backpressure_drops: u64,
pub frames_decoded: u64,
pub output_drops: u64,
pub decode_errors: u64,
pub reconfigurations: u64,
pub frames_in_flight: usize,
pub last_decode_latency_us: u64,
pub max_decode_latency_us: u64,
pub last_platform_status: Option<i32>,
}Expand description
Cumulative decoder and backpressure statistics.
Fields
access_units_received: u64Encoded access units offered to the decoder.
access_units_submitted: u64Access units accepted by the platform decoder.
waiting_drops: u64Access units ignored while waiting for parameter sets or a keyframe.
backpressure_drops: u64Access units dropped because the decoder queue was full.
frames_decoded: u64Successful decoded frames received from the platform.
output_drops: u64Decoded frames replaced before the application consumed them.
decode_errors: u64Synchronous or asynchronous platform decoder errors.
reconfigurations: u64Number of decoder session configurations or reconfigurations.
frames_in_flight: usizeFrames currently owned by the platform decoder.
last_decode_latency_us: u64Most recent submit-to-output latency in microseconds.
max_decode_latency_us: u64Highest observed submit-to-output latency in microseconds.
last_platform_status: Option<i32>Most recent native platform error code.